package cc.fascinated.bat.features.logging.listeners;

import cc.fascinated.bat.common.EmbedDescriptionBuilder;
import cc.fascinated.bat.common.EmbedUtils;
import cc.fascinated.bat.event.EventListener;
import cc.fascinated.bat.features.logging.LogFeature;
import cc.fascinated.bat.features.logging.LogType;
import cc.fascinated.bat.model.BatGuild;
import cc.fascinated.bat.model.BatUser;
import lombok.NonNull;
import net.dv8tion.jda.api.events.guild.member.GuildMemberJoinEvent;
import net.dv8tion.jda.api.events.guild.member.GuildMemberRemoveEvent;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.ApplicationContext;
import org.springframework.stereotype.Component;

/**
 * @author Fascinated (fascinated7)
 */
@Component
public class MemberListener implements EventListener {
    private final LogFeature logFeature;

    @Autowired
    public MemberListener(@NonNull ApplicationContext context) {
        this.logFeature = context.getBean(LogFeature.class);
    }

    @Override
    public void onGuildMemberJoin(@NonNull BatGuild guild, @NonNull BatUser user, @NonNull GuildMemberJoinEvent event) {
        if (user.getDiscordUser().isBot()) return;

        logFeature.sendLog(guild, LogType.MEMBER_JOIN, EmbedUtils.successEmbed()
                .setDescription(new EmbedDescriptionBuilder("Member Joined")
                        .appendLine("Member: %s".formatted(user.getDiscordUser().getAsMention()), true)
                        .appendLine("Username: %s".formatted(user.getDiscordUser().getName()), true)
                        .appendLine("Snowflake: %s".formatted(user.getId()), true)
                        .build())
                .build());
    }

    @Override
    public void onGuildMemberLeave(@NonNull BatGuild guild, BatUser user, @NonNull GuildMemberRemoveEvent event) {
        if (user.getDiscordUser().isBot()) return;

        logFeature.sendLog(guild, LogType.MEMBER_LEAVE, EmbedUtils.errorEmbed()
                .setDescription(new EmbedDescriptionBuilder("Member Left")
                        .appendLine("Member: %s".formatted(user.getDiscordUser().getAsMention()), true)
                        .appendLine("Username: %s".formatted(user.getDiscordUser().getName()), true)
                        .appendLine("Snowflake: %s".formatted(user.getId()), true)
                        .build())
                .build());
    }
}
